@@ -2,7 +2,7 @@ import os, sys, requests, time
 from dataclasses import dataclass, field
 from datetime import datetime
 from typing import List
-import xmltodict
+from xsdata.formats.dataclass.parsers import XmlParser
 
 def wget(url, verify=True):
 	to = url.split('/')[-1].replace('%20','_')
@@ -518,19 +518,4 @@ end
 				exe("rm {0}".format(foil))
 
 	def clean(self,emptyflag=False):
-		self.destroy(emptyflag)
-
-def xmlfile_to_dict(xmlfile):
-	with open(xmlfile,"r") as reader:
-		contents = reader.readlines()
-	return xmltodict.parse(''.join(contents))
-
-def xml_to_dict(xmlcontent):
-	return xmltodict.parse(xmlcontent)
-
-def dict_to_xml(dyct):
-	return xmltodict.unparse(dyct, pretty=True)
-
-def dict_to_xmlfile(dyct,xmlfile):
-	with open(xmlfile,"w+") as writer:
-		writer.write(xmltodict.unparse(dyct, pretty=True))
\ No newline at end of file
+		self.destroy(emptyflag)
\ No newline at end of file
